import { useState } from "react";

const useScriptLoader = () => {
  const [isLoaded, setIsLoaded] = useState();

  const loadScript = src => {
    return new Promise((resolve, reject) => {
      // Create script element and set attributes
      const script = document.createElement("script");
      script.type = "text/javascript";
      script.async = true;
      script.src = src;

      // Append the script to the DOM
      const el = document.getElementsByTagName("script")[0];
      el.parentNode.insertBefore(script, el);

      // Resolve the promise once the script is loaded
      script.addEventListener("load", () => {
        setIsLoaded(true);
        resolve(script);
      });

      // Catch any errors while loading the script
      script.addEventListener("error", () => {
        reject(new Error(`${src} failed to load.`));
      });
    });
  };

  const load = ({ src, globalName }) => {
    return new Promise(async (resolve, reject) => {
      if (!isLoaded) {
        let interval = null;

        try {
          await loadScript(src);

          interval = setInterval(() => {
            if (window[globalName]) {
              clearInterval(interval);

              resolve(window[globalName]);
            }
          }, 500);
        } catch (e) {
          clearInterval(interval);
          reject(e);
        }
      } else {
        resolve(window[globalName]);
      }
    });
  };

  return {
    load
  };
};

export default useScriptLoader;
